@@ -42,7 +42,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  * ------------------------------------------------------------------------
  *
  * See the file ChangeLog for a revision history.  */
@@ -55,6 +55,8 @@
    deep inside Xlib.
 */
 
+#include <config.h>
+
 #include <signal.h>
 #if HAVE_UNISTD_H
 # include <unistd.h>
