@@ -1,6 +1,6 @@
 /*
  * common.h -- Common definitions for X and Windows NT versions of XBoard
- * $Id: common.h,v 1.41 1996/12/19 22:42:52 mann Exp $
+ * $Id: common.h,v 1.47 1997/05/17 07:33:03 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -87,7 +87,6 @@ int pclose(FILE *);
 
 /* End compatibility grunge */
 
-
 #define BOARD_SIZE		8
 #define DROP_RANK               -3
 #define MAX_MOVES		1000
@@ -108,9 +107,10 @@ int pclose(FILE *);
 #define SECOND_HOST		"localhost"
 #define TELNET_PROGRAM          "telnet"
 #define MATCH_MODE		"False"
-#define INIT_STRING		"new\nbeep\nrandom\neasy\n"
+#define INIT_STRING		"new\nbeep\nrandom\nhard\n"
 #define WHITE_STRING		"white\ngo\n"
 #define BLACK_STRING		"black\ngo\n"
+#define REUSE_CHESS_PROGRAMS    1
 #define DEFAULT_SIZE            "Large"
 #define WHITE_PIECE_COLOR	"#FFFFCC"
 #define BLACK_PIECE_COLOR	"#202020"
@@ -118,14 +118,6 @@ int pclose(FILE *);
 #define DARK_SQUARE_COLOR	"#77A26D"
 #define BELLCHAR                '\007'
 #define NULLCHAR                '\000'
-#define COLOR_SHOUT             "green"
-#define COLOR_SSHOUT            "green,black,1"
-#define COLOR_CHANNEL1          "cyan"
-#define COLOR_CHANNEL           "cyan,black,1"
-#define COLOR_KIBITZ            "magenta,black,1"
-#define COLOR_TELL              "yellow,black,1"
-#define COLOR_CHALLENGE         "red,black,1"
-#define COLOR_NORMAL            "default"
 
 typedef enum {
     BeginningOfGame, MachinePlaysWhite, MachinePlaysBlack,
@@ -149,8 +141,9 @@ typedef enum {
     WhiteKingSideCastleWild, WhiteQueenSideCastleWild,
     WhitePromotionKnight, WhitePromotionBishop,
     WhitePromotionRook, WhitePromotionQueen,
-    BlackPromotionKnight, BlackPromotionBishop,
-    BlackPromotionRook, BlackPromotionQueen,
+    WhitePromotionKing, BlackPromotionKnight,
+    BlackPromotionBishop, BlackPromotionRook,
+    BlackPromotionQueen, BlackPromotionKing,
     BlackKingSideCastle, BlackQueenSideCastle,
     BlackKingSideCastleWild, BlackQueenSideCastleWild,
     WhiteCapturesEnPassant, BlackCapturesEnPassant,
@@ -160,6 +153,11 @@ typedef enum {
     BadMove, Comment, AmbiguousMove, PositionDiagram, ElapsedTime, PGNTag
   } ChessMove;
 
+typedef enum {
+    ColorShout, ColorSShout, ColorChannel1, ColorChannel, ColorKibitz,
+    ColorTell, ColorChallenge, ColorNormal, ColorNone, NColorClasses
+} ColorClass;
+
 typedef struct {
 #if !defined(_amigados)
     char *whitePieceColor;
@@ -192,6 +190,7 @@ typedef struct {
     char *icsPort;
     char *icsCommPort;  /* if set, use serial port instead of tcp host/port */
     char *icsLogon;     /* Hack to permit variable logon scripts. */
+    char *icsHelper;
     Boolean icsInputBox;
     Boolean useTelnet;
     char *telnetProgram;
@@ -215,10 +214,13 @@ typedef struct {
     char *clockFont;
     char *messageFont;
     char *coordFont;
+    char *tagsFont; /* WinBoard only */
+    char *commentFont; /* WinBoard only */
+    char *icsFont; /* WinBoard only */
     Boolean ringBellAfterMoves;
     Boolean autoCallFlag;
     Boolean flipView;
-    char *cmailGameName;
+    char *cmailGameName; /* xboard only */
     Boolean alwaysPromoteToQueen;
     Boolean oldSaveStyle;
     Boolean quietPlay;
@@ -227,27 +229,22 @@ typedef struct {
     Boolean autoObserve;
     Boolean autoComment;
     Boolean getMoveList;
-    Boolean checkLegality;
-/**** These are used only by xboard: ********/
-    int borderXoffset;
-    int borderYoffset;
-    Boolean titleInWindow;
-/********************************************/
-/**** Currently used only by WinBoard: ******/
-    Boolean localEdit;
-/********************************************/
+    Boolean testLegality;
+    int borderXoffset; /* xboard only */
+    int borderYoffset; /* xboard only */
+    Boolean titleInWindow; /* xboard only */
+    Boolean localLineEditing; /* WinBoard only */
     Boolean zippyTalk;
     Boolean zippyPlay;
-    int flashCount;		/* Number of times to flash */
-    int flashRate;		/* Flashes per second */
+    int flashCount; /* Number of times to flash (xboard only) */
+    int flashRate; /* Flashes per second (xboard only)  */
     Boolean clickClick;	/* If True, use click-click instead of
-			   click-drag-release to move pieces */
-    char *xpmDirectory; /* Path to XPM files to use */
+			   click-drag-release to move pieces. (xboard only) */
+    char *xpmDirectory; /* Path to XPM files to use (xboard only) */
     int msLoginDelay;  /* Delay per character (in msec) while sending
-			  ICS logon script */
-
+			  ICS logon script (xboard only) */
     Boolean colorize;	/* If True, use the following colors to color text */
-    /* Strings for colors, as "fg, bg, bold" */
+    /* Strings for colors, as "fg, bg, bold" (strings used in xboard only) */
     char *colorShout;
     char *colorSShout;
     char *colorChannel1;
@@ -256,6 +253,7 @@ typedef struct {
     char *colorTell;
     char *colorChallenge;
     char *colorNormal;
+    Boolean reuseChessPrograms;
 } AppData, *AppDataPtr;
 
 extern AppData appData;
@@ -274,18 +272,8 @@ typedef struct {
     char *resultDetails;
     char *timeControl;
     char *extraTags;    /* NULL or "[Tag \"Value\"]\n", etc. */
-    /* These are set from the ICS game-start messages, or from PGN tags */ 
-    int whiteRating;
-    int blackRating;
-  /* OK - This is a kludge, so I'd better document it:
-     The player ratings show up before the game creation
-     message on the ICSes, so when the game is actually created,
-     the ratings get zeroed out.
-     If keep_ratings == 1, then ClearGameInfo() does NOT
-     clear the ratings. If keep_ratings == 0, it DOES clear
-     the ratings. ClearGameInfo() is the only routine that
-     honors this, the others simply zero it out. */
-    int keepRatings;
+    int whiteRating;    /* -1 if unknown */
+    int blackRating;    /* -1 if unknown */
 } GameInfo;
 
 
