@@ -1,6 +1,6 @@
 /*
  * zippy.c -- Implements Zippy the Pinhead chess player on ICS in XBoard
- * $Id: zippy.c,v 1.38 1997/05/09 04:27:25 mann Exp $
+ * $Id: zippy.c,v 1.40 1997/07/24 04:50:50 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -397,6 +397,7 @@ int ZippyConverse(buf, i)
      int *i;
 {
     static char lastgreet[MSG_SIZ];
+    int ci;
 
     if (looking_at(buf, i, ") * shouts: *")) {
 	/* Ignore echoes of Zippy's own shouts */
@@ -424,13 +425,21 @@ int ZippyConverse(buf, i)
     }
 
     if (looking_at(buf, i, "* kibitzes: *") && ((random() % 10) < 9)) {
-	Speak("kibitz", NULL);
-	return TRUE;
+	char *player = StripHighlightAndTitle(star_match[0]);
+
+	if (strcmp(player, zippyName) != 0) {
+	    Speak("kibitz", NULL);
+	    return TRUE;
+	}
     }
 
     if (looking_at(buf, i, "* whispers: *") && ((random() % 10) < 9)) {
-	Speak("whisper", NULL);
-	return TRUE;
+	char *player = StripHighlightAndTitle(star_match[0]);
+
+	if (strcmp(player, zippyName) != 0) {
+	    Speak("whisper", NULL);
+	    return TRUE;
+	}
     }
 
     if ((looking_at(buf, i, "You have * message*.") &&
@@ -443,6 +452,7 @@ int ZippyConverse(buf, i)
 
     /* Messages */
     if (looking_at(buf, i, "--* (*:*): *") ||
+	looking_at(buf, i, ". * (*:*): *") ||
 	looking_at(buf, i, "* at *:*: *")) {
 	FILE *f;
 	char *player = StripHighlightAndTitle(star_match[0]);
@@ -459,11 +469,14 @@ int ZippyConverse(buf, i)
     }
 
     /* Channel tells */
-    if (looking_at(buf, i, "*(*): *")) {
+    if ((ci = 1, looking_at(buf, i, "*(*): *")) ||
+        (ci = 2, looking_at(buf, i, "*(*)(*): *"))) {
+	char *player;
 	if (strchr(star_match[0], ' ') ||
 	    strchr(star_match[1], ' ')) return TRUE;
-	if ((random() % 10) < 9) {
-	    Speak("tell", star_match[1]);
+	player = StripHighlightAndTitle(star_match[0]);
+	if (strcmp(player, zippyName) != 0 && (random() % 10) < 9) {
+	    Speak("tell", star_match[ci]);
 	}
 	return TRUE;
     }
